# pytools_pythonpro

## Módulo Intermediário - Pytools/PythonPro

Exercício de aprendizagem referente criação de projetos na linguagem Python, Curso Python Pro.


# Links

Link do site [Python Pro](https://www.python.pro.br)

Link do GitHub [GitHub/GetulioCastro](https://github.com/GetulioCastro/pytools_pythonpro)


# Distintivos 

[![Build Status](https://travis-ci.org/GetulioCastro/pytools_pythonpro.svg?branch=master)](https://travis-ci.org/GetulioCastro/pytools_pythonpro)
[![Atualizações](https://pyup.io/repos/github/GetulioCastro/pytools_pythonpro/shield.svg)](https://pyup.io/repos/github/GetulioCastro/pytools_pythonpro/)
[![Python 3](https://pyup.io/repos/github/GetulioCastro/pytools_pythonpro/python-3-shield.svg)](https://pyup.io/repos/github/GetulioCastro/pytools_pythonpro/)
[![codecov](https://codecov.io/gh/GetulioCastro/pytools_pythonpro/branch/master/graph/badge.svg)](https://codecov.io/gh/GetulioCastro/pytools_pythonpro)


# Versão de Python 

Suportado versão 3 de Python


# Para instalar:
```Console
python3 -m venv .venv
source .venv/bin/activate
pip install -q -r requirements-dev.txt
```

# Para conferir a qualidade do código:
```Console
flake8
```
